==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebDockManagerPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescription } from "./WebDockManagerPaneDescription";
/**
 * @hidden
 */
var WebDockManagerPaneDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerPaneDescriptionMetadata, _super);
    function WebDockManagerPaneDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerPaneDescriptionMetadata.b = function (a) {
        if (WebDockManagerPaneDescriptionMetadata.a == null) {
            WebDockManagerPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerPaneDescriptionMetadata.c(WebDockManagerPaneDescriptionMetadata.a);
        }
        if (a.g(WebDockManagerPaneDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockManagerPaneDescriptionMetadata.a);
    };
    WebDockManagerPaneDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerPane");
    };
    WebDockManagerPaneDescriptionMetadata.d = function (a) {
        WebDockManagerPaneDescriptionMetadata.b(a);
        a.u("WebDockManagerPane", function () { return new WebDockManagerPaneDescription(); });
        a.t("WebDockManagerPane", WebDockManagerPaneDescriptionMetadata.a);
    };
    WebDockManagerPaneDescriptionMetadata.$t = markType(WebDockManagerPaneDescriptionMetadata, 'WebDockManagerPaneDescriptionMetadata');
    WebDockManagerPaneDescriptionMetadata.a = null;
    return WebDockManagerPaneDescriptionMetadata;
}(Base));
export { WebDockManagerPaneDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDockManagerPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescription } from "./WebDockManagerPaneDescription";
/**
 * @hidden
 */
var WebDockManagerPaneDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerPaneDescriptionMetadata, _super);
    function WebDockManagerPaneDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerPaneDescriptionMetadata.b = function (a) {
        if (WebDockManagerPaneDescriptionMetadata.a == null) {
            WebDockManagerPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerPaneDescriptionMetadata.c(WebDockManagerPaneDescriptionMetadata.a);
        }
        if (a.j(WebDockManagerPaneDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockManagerPaneDescriptionMetadata.a);
    };
    WebDockManagerPaneDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerPane");
    };
    WebDockManagerPaneDescriptionMetadata.d = function (a) {
        WebDockManagerPaneDescriptionMetadata.b(a);
        a.aa("WebDockManagerPane", function () { return new WebDockManagerPaneDescription(); });
        a.z("WebDockManagerPane", WebDockManagerPaneDescriptionMetadata.a);
    };
    WebDockManagerPaneDescriptionMetadata.$t = markType(WebDockManagerPaneDescriptionMetadata, 'WebDockManagerPaneDescriptionMetadata');
    WebDockManagerPaneDescriptionMetadata.a = null;
    return WebDockManagerPaneDescriptionMetadata;
}(Base));
export { WebDockManagerPaneDescriptionMetadata };
